\page md_doc_a-features_j-analytical-derivatives Analytical derivatives

Beside proposing standard forward and inverse dynamics algorithms, Pinocchio
also provides efficient implementations of their analytical derivatives. These
derivatives are for instance of primary importance in the context of whole-body
trajectory optimization or more largely, for numerical optimal control. To the
best of our knowledge, Pinocchio is the first rigid body framework which
implements this feature natively.
